Equip

Trait Equip 

pub trait Equip<A>
where A: Agent,
{ // Required method fn equip<E>(self) -> E where E: From<Address<A>>; }

Required Methods

fn equip<E>(self) -> E
where E: From<Address<A>>,

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<A, X> Equip<A> for (Address<A>, X)
where A: Agent,

This implementation is useful for using with supervisors that can return addresses of spawned agents with assigned relations in a tuple.

Source

fn equip<E>(self) -> E
where E: From<Address<A>>,

Implementors

Source

impl<A> Equip<A> for &Context<A>
where A: Agent,

Source

impl<A> Equip<A> for Address<A>
where A: Agent,