pub trait Equip<A>where
A: Agent,{
// Required method
fn equip<E>(self) -> E
where E: From<Address<A>>;
}Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl<A, X> Equip<A> for (Address<A>, X)where
A: Agent,
This implementation is useful for using with supervisors that can return
addresses of spawned agents with assigned relations in a tuple.
impl<A, X> Equip<A> for (Address<A>, X)where
A: Agent,
This implementation is useful for using with supervisors that can return addresses of spawned agents with assigned relations in a tuple.